@@ -11,8 +11,6 @@ import (
 	"sync"
 	"time"
 
-	"github.com/hashicorp/go-multierror"
-
 	"github.com/golang-migrate/migrate/v4/database"
 	iurl "github.com/golang-migrate/migrate/v4/internal/url"
 	"github.com/golang-migrate/migrate/v4/source"
@@ -56,10 +54,10 @@ func (e ErrDirty) Error() string {
 }
 
 type Migrate struct {
-	sourceName   string
-	sourceDrv    source.Driver
-	databaseName string
-	databaseDrv  database.Driver
+	sourceName         string
+	sourceDrv          source.Driver
+	databaseDriverName string
+	databaseDrv        database.Driver
 
 	// Log accepts a Logger interface
 	Log Logger
@@ -93,11 +91,11 @@ func New(sourceURL, databaseURL string) (*Migrate, error) {
 	}
 	m.sourceName = sourceName
 
-	databaseName, err := iurl.SchemeFromURL(databaseURL)
+	databaseDriverName, err := iurl.SchemeFromURL(databaseURL)
 	if err != nil {
 		return nil, fmt.Errorf("failed to parse scheme from database URL: %w", err)
 	}
-	m.databaseName = databaseName
+	m.databaseDriverName = databaseDriverName
 
 	sourceDrv, err := source.Open(sourceURL)
 	if err != nil {
@@ -116,9 +114,9 @@ func New(sourceURL, databaseURL string) (*Migrate, error) {
 
 // NewWithDatabaseInstance returns a new Migrate instance from a source URL
 // and an existing database instance. The source URL scheme is defined by each driver.
-// Use any string that can serve as an identifier during logging as databaseName.
+// Use any string that can serve as an identifier during logging as databaseDriverName.
 // You are responsible for closing the underlying database client if necessary.
-func NewWithDatabaseInstance(sourceURL string, databaseName string, databaseInstance database.Driver) (*Migrate, error) {
+func NewWithDatabaseInstance(sourceURL string, databaseDriverName string, databaseInstance database.Driver) (*Migrate, error) {
 	m := newCommon()
 
 	sourceName, err := iurl.SchemeFromURL(sourceURL)
@@ -127,7 +125,7 @@ func NewWithDatabaseInstance(sourceURL string, databaseName string, databaseInst
 	}
 	m.sourceName = sourceName
 
-	m.databaseName = databaseName
+	m.databaseDriverName = databaseDriverName
 
 	sourceDrv, err := source.Open(sourceURL)
 	if err != nil {
@@ -147,11 +145,11 @@ func NewWithDatabaseInstance(sourceURL string, databaseName string, databaseInst
 func NewWithSourceInstance(sourceName string, sourceInstance source.Driver, databaseURL string) (*Migrate, error) {
 	m := newCommon()
 
-	databaseName, err := iurl.SchemeFromURL(databaseURL)
+	databaseDriverName, err := iurl.SchemeFromURL(databaseURL)
 	if err != nil {
 		return nil, fmt.Errorf("failed to parse scheme from database URL: %w", err)
 	}
-	m.databaseName = databaseName
+	m.databaseDriverName = databaseDriverName
 
 	m.sourceName = sourceName
 
@@ -168,13 +166,13 @@ func NewWithSourceInstance(sourceName string, sourceInstance source.Driver, data
 
 // NewWithInstance returns a new Migrate instance from an existing source and
 // database instance. Use any string that can serve as an identifier during logging
-// as sourceName and databaseName. You are responsible for closing down
+// as sourceName and databaseDriverName. You are responsible for closing down
 // the underlying source and database client if necessary.
-func NewWithInstance(sourceName string, sourceInstance source.Driver, databaseName string, databaseInstance database.Driver) (*Migrate, error) {
+func NewWithInstance(sourceName string, sourceInstance source.Driver, databaseDriverName string, databaseInstance database.Driver) (*Migrate, error) {
 	m := newCommon()
 
 	m.sourceName = sourceName
-	m.databaseName = databaseName
+	m.databaseDriverName = databaseDriverName
 
 	m.sourceDrv = sourceInstance
 	m.databaseDrv = databaseInstance
@@ -526,7 +524,7 @@ func (m *Migrate) read(from int, to int, ret chan<- interface{}) {
 	}
 }
 
-// readUp reads up migrations from `from` limitted by `limit`.
+// readUp reads up migrations from `from` limited by `limit`.
 // limit can be -1, implying no limit and reading until there are no more migrations.
 // Each migration is then written to the ret channel.
 // If an error occurs during reading, that error is written to the ret channel, too.
@@ -626,7 +624,7 @@ func (m *Migrate) readUp(from int, limit int, ret chan<- interface{}) {
 	}
 }
 
-// readDown reads down migrations from `from` limitted by `limit`.
+// readDown reads down migrations from `from` limited by `limit`.
 // limit can be -1, implying no limit and reading until there are no more migrations.
 // Each migration is then written to the ret channel.
 // If an error occurs during reading, that error is written to the ret channel, too.
@@ -781,7 +779,7 @@ func (m *Migrate) versionExists(version uint) (result error) {
 	if err == nil {
 		defer func() {
 			if errClose := up.Close(); errClose != nil {
-				result = multierror.Append(result, errClose)
+				result = errors.Join(result, errClose)
 			}
 		}()
 	}
@@ -796,7 +794,7 @@ func (m *Migrate) versionExists(version uint) (result error) {
 	if err == nil {
 		defer func() {
 			if errClose := down.Close(); errClose != nil {
-				result = multierror.Append(result, errClose)
+				result = errors.Join(result, errClose)
 			}
 		}()
 	}
@@ -954,7 +952,7 @@ func (m *Migrate) unlock() error {
 // if a prevErr is not nil.
 func (m *Migrate) unlockErr(prevErr error) error {
 	if err := m.unlock(); err != nil {
-		return multierror.Append(prevErr, err)
+		prevErr = errors.Join(prevErr, err)
 	}
 	return prevErr
 }
