@@ -15,12 +15,10 @@ import (
 	"strings"
 	"testing"
 
-	dockertypes "github.com/docker/docker/api/types"
 	dockercontainer "github.com/docker/docker/api/types/container"
 	dockerimage "github.com/docker/docker/api/types/image"
 	dockernetwork "github.com/docker/docker/api/types/network"
 	dockerclient "github.com/docker/docker/client"
-	"github.com/hashicorp/go-multierror"
 )
 
 func NewDockerContainer(t testing.TB, image string, env []string, cmd []string) (*DockerContainer, error) {
@@ -64,7 +62,7 @@ type DockerContainer struct {
 	Cmd                []string
 	ContainerId        string
 	ContainerName      string
-	ContainerJSON      dockertypes.ContainerJSON
+	ContainerJSON      dockercontainer.InspectResponse
 	containerInspected bool
 	keepForDebugging   bool
 }
@@ -80,7 +78,7 @@ func (d *DockerContainer) PullImage() (err error) {
 	}
 	defer func() {
 		if errClose := r.Close(); errClose != nil {
-			err = multierror.Append(errClose)
+			err = errors.Join(err, errClose)
 		}
 	}()
 
@@ -201,7 +199,7 @@ func (d *DockerContainer) Logs() (io.ReadCloser, error) {
 	})
 }
 
-func (d *DockerContainer) portMapping(selectFirst bool, cPort int) (containerPort uint, hostIP string, hostPort uint, err error) { // nolint:unparam
+func (d *DockerContainer) portMapping(selectFirst bool, cPort int) (hostIP string, hostPort uint, err error) {
 	if !d.containerInspected {
 		if err := d.Inspect(); err != nil {
 			d.t.Fatal(err)
@@ -213,21 +211,20 @@ func (d *DockerContainer) portMapping(selectFirst bool, cPort int) (containerPor
 			// Skip ahead until we find the port we want
 			continue
 		}
-		for _, binding := range bindings {
-
+		if len(bindings) > 0 {
+			binding := bindings[0]
 			hostPortUint, err := strconv.ParseUint(binding.HostPort, 10, 64)
 			if err != nil {
-				return 0, "", 0, err
+				return "", 0, err
 			}
-
-			return uint(port.Int()), binding.HostIP, uint(hostPortUint), nil // nolint: staticcheck
+			return bindings[0].HostIP, uint(hostPortUint), nil
 		}
 	}
 
 	if selectFirst {
-		return 0, "", 0, errors.New("no port binding")
+		return "", 0, errors.New("no port binding")
 	} else {
-		return 0, "", 0, errors.New("specified port not bound")
+		return "", 0, errors.New("specified port not bound")
 	}
 }
 
@@ -235,7 +232,7 @@ func (d *DockerContainer) Host() string {
 	if d == nil {
 		panic("Cannot get host for a nil *DockerContainer")
 	}
-	_, hostIP, _, err := d.portMapping(true, -1)
+	hostIP, _, err := d.portMapping(true, -1)
 	if err != nil {
 		d.t.Fatal(err)
 	}
@@ -251,7 +248,7 @@ func (d *DockerContainer) Port() uint {
 	if d == nil {
 		panic("Cannot get port for a nil *DockerContainer")
 	}
-	_, _, port, err := d.portMapping(true, -1)
+	_, port, err := d.portMapping(true, -1)
 	if err != nil {
 		d.t.Fatal(err)
 	}
@@ -262,14 +259,14 @@ func (d *DockerContainer) PortFor(cPort int) uint {
 	if d == nil {
 		panic("Cannot get port for a nil *DockerContainer")
 	}
-	_, _, port, err := d.portMapping(false, cPort)
+	_, port, err := d.portMapping(false, cPort)
 	if err != nil {
 		d.t.Fatal(err)
 	}
 	return port
 }
 
-func (d *DockerContainer) NetworkSettings() dockertypes.NetworkSettings {
+func (d *DockerContainer) NetworkSettings() dockercontainer.NetworkSettings {
 	if d == nil {
 		panic("Cannot get network settings for a nil *DockerContainer")
 	}
